// Ionic Starter App

// angular.module is a global place for creating, registering and retrieving Angular modules
// 'starter' is the name of this angular module example (also set in a <body> attribute in index.html)
// the 2nd parameter is an array of 'requires'
var app = angular.module('app', ['ionic', 'ionic-material', 'ngCordova', 'ionicLazyLoad', 'ngCordovaOauth', 'ngResource', 'ionic-datepicker']);

app.run(function ($ionicPlatform, $cordovaSQLite) {
    $ionicPlatform.ready(function () {
        // Hide the accessory bar by default (remove this to show the accessory bar above the keyboard
        // for form inputs)

        if (window.cordova && window.cordova.plugins.Keyboard) {
            cordova.plugins.Keyboard.hideKeyboardAccessoryBar(true);
        }
        if (window.StatusBar) {
            StatusBar.styleDefault();
        }
    });
})
app.filter('trusted', ['$sce', function ($sce) {
    return function (url) {
        var video_id = url.split('v=')[1].split('&')[0];
        return $sce.trustAsResourceUrl("https://www.youtube.com/embed/" + video_id);
    };
}]);
app.filter('cut', function () {
    return function (value, wordwise, max, tail) {
        if (!value) return '';

        max = parseInt(max, 10);
        if (!max) return value;
        if (value.length <= max) return value;

        value = value.substr(0, max);
        if (wordwise) {
            var lastspace = value.lastIndexOf(' ');
            if (lastspace != -1) {
                //Also remove . and , so its gives a cleaner result.
                if (value.charAt(lastspace - 1) == '.' || value.charAt(lastspace - 1) == ',') {
                    lastspace = lastspace - 1;
                }
                value = value.substr(0, lastspace);
            }
        }

        return value + (tail || ' …');
    };
});

app.config(function ($stateProvider, $urlRouterProvider, ionicDatePickerProvider) {
    var datePickerObj = {
        inputDate: new Date(),
        titleLabel: 'Select a Date',
        setLabel: 'Set',
        todayLabel: 'Today',
        closeLabel: 'Close',
        mondayFirst: false,
        weeksList: ["S", "M", "T", "W", "T", "F", "S"],
        monthsList: ["Jan", "Feb", "March", "April", "May", "June", "July", "Aug", "Sept", "Oct", "Nov", "Dec"],
        templateType: 'popup',
        from: new Date(2012, 8, 1),
        to: new Date(2018, 8, 1),
        showTodayButton: true,
        dateFormat: 'dd MMMM yyyy',
        closeOnSelect: false,
        disableWeekdays: []
    };
    ionicDatePickerProvider.configDatePicker(datePickerObj);

    $stateProvider

    .state('app', {
        url: '/app',
        abstract: true,
        templateUrl: 'templates/menu.html',
        controller: 'AppCtrl'
    })

    
    .state('app.home', {
        url: '/home',
        views: {
            'menuContent': {
                templateUrl: 'templates/home.html',
                controller: 'HomeCtrl'
            }
        }
    })
    
    .state('app.animals', {
        url: '/animals',
        views: {
            'menuContent': {
                templateUrl: 'templates/animals.html',
                controller: 'AnimalsCtrl'
            }
        }
    })
    .state('app.news', {
        url: '/news',
        views: {
            'menuContent': {
                templateUrl: 'templates/news.html',
                controller: 'NewsCtrl'
            }
        }
    })
    .state('app.inmap', {
        url: '/inmap',
        views: {
            'menuContent': {
                templateUrl: 'templates/inmap.html',
                controller: 'InMapCtrl'
            }
        }
    })
    .state('app.outmap', {
        url: '/outmap',
        views: {
            'menuContent': {
                templateUrl: 'templates/outmap.html',
                controller: 'OutMapCtrl'
            }
        }
    })
    .state('app.about', {
        url: '/about',
        views: {
            'menuContent': {
                templateUrl: 'templates/about.html',
                controller: 'AboutCtrl'
            }
        }
    })
    .state('app.animalsdetails', {
        url: '/animalsdetails/:ID?',
        views: {
            'menuContent': {
                templateUrl: 'templates/animalsdetails.html',
                controller: 'AnimalsDetailsCtrl'
            }
        }
    })
    .state('app.servicedetails', {
        url: '/servicedetails/:ID?',
        views: {
            'menuContent': {
                templateUrl: 'templates/servicedetails.html',
                controller: 'ServiceDetailsCtrl'
            }
        }
    })
    .state('app.newsdetails', {
        url: '/newsdetails/:ID?',
        views: {
            'menuContent': {
                templateUrl: 'templates/newsdetails.html',
                controller: 'NewsDetailsCtrl'
            }
        }
    })
    .state('app.servicecategory', {
        url: '/servicecategory',
        views: {
            'menuContent': {
                templateUrl: 'templates/servicecategory.html',
                controller: 'ServiceCategoryCtrl'
            }
        }
    })
    
    .state('app.services', {
        url: '/services/:ID?',
        views: {
            'menuContent': {
                templateUrl: 'templates/services.html',
                controller: 'ServicesCtrl'
            }
        }
    })
    
    .state('app.vistortype', {
        url: '/vistortype',
        views: {
            'menuContent': {
                templateUrl: 'templates/vistortype.html',
                controller: 'VistortypeCtrl'
            }
        }
    })
    .state('app.vistor', {
        url: '/vistor/:ID?',
        views: {
            'menuContent': {
                templateUrl: 'templates/vistor.html',
                controller: 'VistorCtrl'
            }
        }
    })
    .state('app.tickettype', {
        url: '/tickettype',
        views: {
            'menuContent': {
                templateUrl: 'templates/tickettype.html',
                controller: 'TickettypeCtrl'
            }
        }
    })
    .state('app.ticket', {
        url: '/ticket/:ID?',
        views: {
            'menuContent': {
                templateUrl: 'templates/ticket.html',
                controller: 'TicketCtrl'
            }
        }
    })

        .state('app.competitions', {
            url: '/competitions',
            views: {
                'menuContent': {
                    templateUrl: 'templates/competitions.html',
                    controller: 'CompetitionsCtrl'
                }
            }
        })
        .state('app.knowledge', {
        url: '/knowledge',
        views: {
            'menuContent': {
                templateUrl: 'templates/knowledge.html',
                controller: 'knowledgeCtrl'
            }
        }
    })
    .state('app.questionnaire', {
        url: '/questionnaire',
        views: {
            'menuContent': {
                templateUrl: 'templates/questionnaire.html',
                controller: 'QuestionnaireCtrl'
            }
        }
    })
    .state('app.questionnairedetails', {
        url: '/questionnairedetails/:ID?',
            views: {
                'menuContent': {
                    templateUrl: 'templates/questionnairedetails.html',
                    controller: 'QuestionnaireDetailsCtrl'
                }
            }
    })
    .state('app.questionnairesub', {
        url: '/questionnairesub/:ID?',
            views: {
                'menuContent': {
                    templateUrl: 'templates/questionnairesub.html',
                    controller: 'QuestionnaireSubCtrl'
                }
            }
        })  
    .state('app.settings', {
        url: '/settings',
        views: {
            'menuContent': {
                templateUrl: 'templates/settings.html',
                controller: 'SettingsCtrl'
            }
        }
    })
    .state('app.suggestation', {
        url: '/suggestation',
        views: {
            'menuContent': {
                templateUrl: 'templates/suggestation.html',
                controller: 'SuggestationCtrl'
            }
        }
    })
    
    
    .state('app.visitorrequest', {
        url: '/visitorrequest',
        views: {
            'menuContent': {
                templateUrl: 'templates/visitorrequest.html',
                controller: 'VisitorRequestCtrl'
            }
        }
    })
    .state('app.competitiondetails', {
        url: '/competitiondetails/:ID?',
        views: {
            'menuContent': {
                templateUrl: 'templates/competitiondetails.html',
                controller: 'CompetitionDetailsCtrl'
            }
        }
    })
    .state('app.loginlist', {
        url: '/loginlist',
        views: {
            'menuContent': {
                templateUrl: 'templates/loginlist.html',
                controller: 'LoginListCtrl'
            }
        }
    })
    .state('app.videosimages', {
        url: '/videosimages',
        views: {
            'menuContent': {
                templateUrl: 'templates/videosimages.html',
                controller: 'VideosImagesCtrl'
            }
        }
    })
    .state('app.videosimagesdetails', {
        url: '/videosimagesdetails/:ID?',
        views: {
            'menuContent': {
                templateUrl: 'templates/videosimagesdetails.html',
                controller: 'VideoImagesDetailsCtrl'
            }
        }
      })
      .state('app.requests', {
        url: '/requests',
        views: {
          'menuContent': {
            templateUrl: 'templates/requests.html',
            controller: 'RequestsCtrl'
          }
        }
      })
    ;

    // if none of the above states are matched, use this as the fallback
    $urlRouterProvider.otherwise('/app/home');
});
//app.filter('trusted', ['$sce', function ($sce) {
//    return function (url) {
//        var video_id = url.split('v=')[1].split('&')[0];
//        return $sce.trustAsResourceUrl("https://www.youtube.com/embed/" + video_id);
//    };
//}]);
